==> tuoyuan-vue-json-schema-1.2.1.tgz: package/lib/index.js <==
import ElementUI from 'element-ui'
import 'element-ui/lib/theme-chalk/index.css'
import VueCodeMirror from 'vue-codemirror'

import Icon from '../packages/icon/index.js'
import BTip from '../packages/b-tip/index.js'
import BForm from '../packages/b-form/index.js'
import JsonSchemaEditor from '../packages/json-schema-editor/index'
import SchemaFormCompos from '../packages/json-schema-form/index'

const {
  SchemaForm,
  formObject,
  formArray,
  formString,
  formNumber,
  formInteger,
  formBoolean,
  formOneOf,
  formRef,
  codeMirror
} = SchemaFormCompos

const components = [
  BForm,
  BTip,
  Icon,
  JsonSchemaEditor,
  SchemaForm,
  formObject,
  formArray,
  formString,
  formNumber,
  formInteger,
  formBoolean,
  formOneOf,
  formRef,
  codeMirror
]

const install = function (Vue, opts = {}) {
  components.forEach(component => {
    Vue.component(component.name, component)
  })

  Vue.use(ElementUI, { size: opts.ElementUISize || 'mini' })
  Vue.use(VueCodeMirror)

  Vue.prototype.$JSONSCHEMA = {
    // 业务组件
    businessCompo: opts.businessCompo || []
  }
  // 注册业务组件
  if (opts.businessCompo && opts.businessCompo.length) {
    opts.businessCompo.forEach(component => {
      if (!component.type) {
        return console.warn('The attribute \'type\' does not exist when registering a business component')
      }
      if (!component.component) {
        return console.warn('The attribute \'component\' does not exist when registering a business component')
      }
      if (!(component.dataType && component.dataType.length)) {
        return console.warn('The business component has no form type set')
      }
      Vue.component(`business-${component.type}`, component.component)
    })
  }
}

if (typeof window !== 'undefined' && window.Vue) {
  install(window.Vue)
}

export default {
  version: '1.0.0',
  install
}

==> tuoyuan-vue-json-schema-1.2.7.tgz: package/lib/index.js <==
import ElementUI from 'element-ui'
import 'element-ui/lib/theme-chalk/index.css'
import VueCodeMirror from 'vue-codemirror'

import Icon from '../packages/icon/index.js'
import BTip from '../packages/b-tip/index.js'
import BForm from '../packages/b-form/index.js'
import JsonSchemaEditor from '../packages/json-schema-editor/index.js'
import SchemaFormCompos from '../packages/json-schema-form/index.js'

const {
  SchemaForm,
  formObject,
  formArray,
  formString,
  formNumber,
  formInteger,
  formBoolean,
  formOneOf,
  formRef,
  codeMirror
} = SchemaFormCompos

const components = [
  BForm,
  BTip,
  Icon,
  JsonSchemaEditor,
  SchemaForm,
  formObject,
  formArray,
  formString,
  formNumber,
  formInteger,
  formBoolean,
  formOneOf,
  formRef,
  codeMirror
]

const install = function (Vue, opts = {}) {
  components.forEach(component => {
    Vue.component(component.name, component)
  })

  Vue.use(ElementUI, { size: opts.ElementUISize || 'mini' })
  Vue.use(VueCodeMirror)

  Vue.prototype.$JSONSCHEMA = {
    // 业务组件
    businessCompo: opts.businessCompo || []
  }
  // 注册业务组件
  if (opts.businessCompo && opts.businessCompo.length) {
    opts.businessCompo.forEach(component => {
      if (!component.type) {
        return console.warn('The attribute \'type\' does not exist when registering a business component')
      }
      if (!component.component) {
        return console.warn('The attribute \'component\' does not exist when registering a business component')
      }
      if (!(component.dataType && component.dataType.length)) {
        return console.warn('The business component has no form type set')
      }
      Vue.component(`business-${component.type}`, component.component)
    })
  }
}

if (typeof window !== 'undefined' && window.Vue) {
  install(window.Vue)
}

export default {
  version: '1.0.0',
  install
}
